@@ -1236,7 +1236,7 @@ class TimelogControllerTest < Redmine::ControllerTest
     with_settings :date_format => '%m/%d/%Y' do
       get :index, :params => {:format => 'csv'}
       assert_response :success
-      assert_equal 'text/csv; header=present', response.content_type
+      assert_equal 'text/csv', response.content_type
     end
   end
 
@@ -1244,7 +1244,7 @@ class TimelogControllerTest < Redmine::ControllerTest
     with_settings :date_format => '%m/%d/%Y' do
       get :index, :params => {:project_id => 1, :format => 'csv'}
       assert_response :success
-      assert_equal 'text/csv; header=present', response.content_type
+      assert_equal 'text/csv', response.content_type
     end
   end
 
